<?php
/**
 * The Header for our theme.
 * @package Charity Fundraiser
 */
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
  <meta charset="<?php bloginfo( 'charset' ); ?>">
  <meta name="viewport" content="width=device-width">
  <link rel="profile" href="<?php echo esc_url( __( 'http://gmpg.org/xfn/11', 'charity-fundraiser' ) ); ?>">
  <?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
  <header role="banner">
    <a class="screen-reader-text skip-link" href="#maincontent"><?php esc_html_e( 'Skip to content', 'charity-fundraiser' ); ?><span class="screen-reader-text"><?php esc_html_e('Skip to Content','charity-fundraiser'); ?></span></a>
    <div class="top-bar">
      <div class="container">
        <div class="row">
          <div class="logo col-lg-3 col-md-3">
            <?php if( has_custom_logo() ){ charity_fundraiser_the_custom_logo();
             }else{ ?>
            <h1><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php $description = get_bloginfo( 'description', 'display' );
            if ( $description || is_customize_preview() ) : ?> 
              <p class="site-description"><?php echo esc_html($description); ?></p>
            <?php endif; }?>
          </div>
          <div class="col-lg-3 col-md-3">
            <div class="contact-details">
              <div class="row">
                <?php if ( get_theme_mod('charity_fundraiser_email_text','') != "" ) {?>
                  <div class="col-lg-2 col-md-2 p-0 conatct-font">
                    <i class="fas fa-envelope"></i>
                  </div>
                  <div class="col-lg-8 col-md-8">
                    <?php if ( get_theme_mod('charity_fundraiser_email_text','') != "" ) {?>
                      <p class="bold-font"><?php echo esc_html( get_theme_mod('charity_fundraiser_email_text','') ); ?></p>
                    <?php }?>
                    <?php if ( get_theme_mod('charity_fundraiser_email','') != "" ) {?>
                      <p><?php echo esc_html( get_theme_mod('charity_fundraiser_email','') ); ?></p>
                    <?php }?>
                  </div>
                <?php }?>
              </div>
            </div>
          </div>          
          <div class="col-lg-3 col-md-3">
            <div class="contact-details">
              <div class="row">
                <?php if ( get_theme_mod('charity_fundraiser_call_text','') != "" ) {?>
                  <div class="col-lg-2 col-md-2 p-0 conatct-font">
                    <i class="fas fa-phone"></i>
                  </div>
                  <div class="col-lg-8 col-md-8">
                    <?php if ( get_theme_mod('charity_fundraiser_call_text','') != "" ) {?>
                      <p class="bold-font"><?php echo esc_html( get_theme_mod('charity_fundraiser_call_text','' )); ?></p>
                    <?php }?>
                    <?php if ( get_theme_mod('charity_fundraiser_call_number','') != "" ) {?>
                      <p><?php echo esc_html( get_theme_mod('charity_fundraiser_call_number','' )); ?></p>
                    <?php }?>
                  </div>
                <?php }?>
              </div>
            </div>
          </div>
          <div class="col-lg-3 col-md-3">
            <div class="social-media">
              <?php if( get_theme_mod( 'charity_fundraiser_facebook' ) != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'charity_fundraiser_facebook','' ) ); ?>"><i class="fab fa-facebook-f"></i><span class="screen-reader-text"><?php esc_html_e('Facebook','charity-fundraiser'); ?></span></a>
              <?php } ?>
              <?php if( get_theme_mod( 'charity_fundraiser_twitter' ) != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'charity_fundraiser_twitter','' ) ); ?>"><i class="fab fa-twitter"></i><span class="screen-reader-text"><?php esc_html_e('Twitter','charity-fundraiser'); ?></span></a>
              <?php } ?>
              <?php if( get_theme_mod( 'charity_fundraiser_google') != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'charity_fundraiser_google','' ) ); ?>"><i class="fab fa-google-plus-g"></i><span class="screen-reader-text"><?php esc_html_e('Google Plus','charity-fundraiser'); ?></span></a>
              <?php } ?>
              <?php if( get_theme_mod( 'charity_fundraiser_pintrest' ) != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'charity_fundraiser_pintrest','' ) ); ?>"><i class="fab fa-pinterest-p"></i><span class="screen-reader-text"><?php esc_html_e('Pinterest','charity-fundraiser'); ?></span></a>
              <?php } ?>
              <?php if( get_theme_mod( 'charity_fundraiser_insta' ) != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'charity_fundraiser_insta','' ) ); ?>"><i class="fab fa-instagram"></i><span class="screen-reader-text"><?php esc_html_e('Instagram','charity-fundraiser'); ?></span></a>
              <?php } ?>
              <?php if( get_theme_mod( 'charity_fundraiser_linkdin' ) != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'charity_fundraiser_linkdin','' ) ); ?>"><i class="fab fa-linkedin-in"></i><span class="screen-reader-text"><?php esc_html_e('Linkedin','charity-fundraiser'); ?></span></a>
              <?php } ?>
              <?php if( get_theme_mod( 'charity_fundraiser_youtube' ) != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'charity_fundraiser_youtube','' ) ); ?>"><i class="fab fa-youtube"></i><span class="screen-reader-text"><?php esc_html_e('Youtube','charity-fundraiser'); ?></span></a>
              <?php } ?>
            </div>
          </div>
        </div>
      </div>    
      <div id="header">
        <div class="container">
          <div class="menu-sec">
            <div class="row m-0">
              <div class="menubox col-lg-9 col-md-6 col-3">
                <div class="toggle-menu responsive-menu">
                  <button onclick="resMenu_open()" role="tab"><i class="fas fa-bars"></i><span class="screen-reader-text"><?php esc_html_e('Open Menu','charity-fundraiser'); ?></span></button>
                </div>
                <div id="sidelong-menu" class="nav side-nav">
                  <nav id="primary-site-navigation" class="nav-menu" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'charity-fundraiser' ); ?>">
                    <a href="javascript:void(0)" class="closebtn responsive-menu" onclick="resMenu_close()"><i class="fas fa-times"></i><span class="screen-reader-text"><?php esc_html_e('Close Menu','charity-fundraiser'); ?></span></a>
                    <?php 
                      wp_nav_menu( array( 
                        'theme_location' => 'primary',
                        'container_class' => 'main-menu-navigation clearfix' ,
                        'menu_class' => 'clearfix',
                        'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
                        'fallback_cb' => 'wp_page_menu',
                      ) ); 
                    ?>
                  </nav>
                </div>
              </div>
              <div class="search-box col-lg-1 col-md-2 col-2">
                <span><i class="fas fa-search"></i></span>
              </div>
              <?php if ( get_theme_mod('charity_fundraiser_donate_text','') != "" ) {?>
              <div class="col-lg-2 col-md-4 col-7 donate-link">              
                <a href="<?php echo esc_html( get_theme_mod('charity_fundraiser_donate_link','') ); ?>"><i class="fas fa-heart"></i><?php echo esc_html( get_theme_mod('charity_fundraiser_donate_text','') ); ?><span class="screen-reader-text"><?php esc_html_e('Donate Button','charity-fundraiser'); ?></span></a>
              </div>
              <?php }?>
            </div>
            <div class="serach_outer">
              <div class="closepop"><i class="far fa-window-close"></i></div>
              <div class="serach_inner">
                <?php get_search_form(); ?>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </header>